@@ -165,11 +165,7 @@ multilevel.indirect <- function(a, b, se.a, se.b, cov.ab = 0, cov.rand, se.cov.r
 
   #......
   # Check input 'check'
-  if (isTRUE(!is.logical(check))) {
-
-    stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
-
-  }
+  if (isTRUE(!is.logical(check))) { stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE) }
 
   #----------------------------------------
 
@@ -177,97 +173,43 @@ multilevel.indirect <- function(a, b, se.a, se.b, cov.ab = 0, cov.rand, se.cov.r
 
     #......
     # Check input 'a', 'b', 'se.a', 'se.b', cov.ab, cov.rand, and se.cov.rand
-    if (isTRUE(mode(a) != "numeric")) {
+    if (isTRUE(mode(a) != "numeric")) { stop("Please specify a numeric value for the argument 'a'.", call. = FALSE) }
 
-      stop("Please specify a numeric value for the argument 'a'.", call. = FALSE)
+    if (isTRUE(mode(b) != "numeric")) { stop("Please specify a numeric value for the argument 'b'.", call. = FALSE) }
 
-    }
+    if (isTRUE(mode(cov.ab) != "numeric")) { stop("Please specify a numeric value for the argument 'cov.ab'.", call. = FALSE) }
 
-    if (isTRUE(mode(b) != "numeric")) {
+    if (isTRUE(mode(cov.rand) != "numeric")) { stop("Please specify a numeric value for the argument 'cov.rand'.", call. = FALSE) }
 
-      stop("Please specify a numeric value for the argument 'b'.", call. = FALSE)
+    if (isTRUE(mode(se.a) != "numeric" || se.a <= 0L)) { stop("Please specify a positive numeric value for the argument 'se.a'.", call. = FALSE) }
 
-    }
+    if (isTRUE(mode(se.b) != "numeric" || se.a <= 0L)) { stop("Please specify a positive numeric value for the argument 'se.b'.", call. = FALSE) }
 
-    if (isTRUE(mode(cov.ab) != "numeric")) {
-
-      stop("Please specify a numeric value for the argument 'cov.ab'.", call. = FALSE)
-
-    }
-
-    if (isTRUE(mode(cov.rand) != "numeric")) {
-
-      stop("Please specify a numeric value for the argument 'cov.rand'.", call. = FALSE)
-
-    }
-
-    if (isTRUE(mode(se.a) != "numeric" || se.a <= 0)) {
-
-      stop("Please specify a positive numeric value for the argument 'se.a'.", call. = FALSE)
-
-    }
-
-    if (isTRUE(mode(se.b) != "numeric" || se.a <= 0)) {
-
-      stop("Please specify a positive numeric value for the argument 'se.b'.", call. = FALSE)
-
-    }
-
-    if (isTRUE(mode(se.cov.rand) != "numeric" || se.cov.rand <= 0)) {
-
-      stop("Please specify a positive numeric value for the argument 'se.cov.rand'.", call. = FALSE)
-
-    }
+    if (isTRUE(mode(se.cov.rand) != "numeric" || se.cov.rand <= 0L)) { stop("Please specify a positive numeric value for the argument 'se.cov.rand'.", call. = FALSE) }
 
     #......
     # Check input 'nrep'
-    if (isTRUE(mode(nrep) != "numeric" || nrep <= 1)) {
-
-      stop("Please specify a positive numeric value greater 1 for the argument 'nrep'.", call. = FALSE)
-
-    }
+    if (isTRUE(mode(nrep) != "numeric" || nrep <= 1L)) { stop("Please specify a positive numeric value greater 1 for the argument 'nrep'.", call. = FALSE) }
 
     #......
     # Check input 'alternative'
-    if (isTRUE(!all(alternative %in% c("two.sided", "less", "greater")))) {
-
-      stop("Character string in the argument 'alternative' does not match with \"two.sided\", \"less\", or \"greater\".",
-           call. = FALSE)
-
-    }
+    if (isTRUE(!all(alternative %in% c("two.sided", "less", "greater")))) { stop("Character string in the argument 'alternative' does not match with \"two.sided\", \"less\", or \"greater\".", call. = FALSE) }
 
     #......
     # Check input 'seed'
-    if (isTRUE(mode(seed) != "numeric" && !is.null(seed))) {
-
-      stop("Please specify a numeric value greater for the argument 'seed'.", call. = FALSE)
-
-    }
+    if (isTRUE(mode(seed) != "numeric" && !is.null(seed))) { stop("Please specify a numeric value greater for the argument 'seed'.", call. = FALSE) }
 
     #......
     # Check input 'conf.level'
-    if (isTRUE(conf.level >= 1L || conf.level <= 0L)) {
-
-      stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.",
-           call. = FALSE)
-
-    }
+    if (isTRUE(conf.level >= 1L || conf.level <= 0L)) { stop("Please specifiy a numeric value between 0 and 1 for the argument 'conf.level'.", call. = FALSE) }
 
     #......
     # Check input 'digits'
-    if (isTRUE(digits %% 1L != 0L || digits < 0L)) {
-
-      stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE)
-
-    }
+    if (isTRUE(digits %% 1L != 0L || digits < 0L)) { stop("Specify a positive integer number for the argument 'digits'.", call. = FALSE) }
 
     #......
     # Check input 'output'
-    if (isTRUE(!is.logical(output))) {
-
-      stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE)
-
-    }
+    if (isTRUE(!is.logical(output))) { stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE) }
 
   }
 
