@@ -81,48 +81,26 @@ na.as <- function(x, value, as.na = NULL, check = TRUE) {
 
   #...............
   # Check if input 'x' is missing
-  if (isTRUE(missing(x))) {
-
-    stop("Please specify a vector, factor, matrix or data frame for the argument 'x'.",
-         call. = FALSE)
-
-  }
+  if (isTRUE(missing(x))) { stop("Please specify a vector, factor, matrix or data frame for the argument 'x'.", call. = FALSE) }
 
   #......
   # Check if input 'x' is NULL
-  if (isTRUE(is.null(x))) {
-
-    stop("Input specified for the argument 'x' is NULL.", call. = FALSE)
-
-  }
+  if (isTRUE(is.null(x))) { stop("Input specified for the argument 'x' is NULL.", call. = FALSE) }
 
   #...............
   # Check if input 'value' is missing
-  if (isTRUE(missing(value))) {
-
-    stop("Please specify a numeric value or character string for the argument 'value'.",
-         call. = FALSE)
-
-  }
+  if (isTRUE(missing(value))) { stop("Please specify a numeric value or character string for the argument 'value'.", call. = FALSE) }
 
   #...............
   # Convert user-missing values into NA
-  if (isTRUE(!is.null(as.na))) {
-
-    x <- misty::as.na(x, na = as.na, check = check)
-
-  }
+  if (isTRUE(!is.null(as.na))) { x <- misty::as.na(x, na = as.na, check = check) }
 
   #-----------------------------------------------------------------------------------
   # Input Check
 
   #...............
   # Check input 'check'
-  if (isTRUE(!is.logical(check))) {
-
-    stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
-
-  }
+  if (isTRUE(!is.logical(check))) { stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE) }
 
   #-----------------------------------------
 
@@ -130,45 +108,25 @@ na.as <- function(x, value, as.na = NULL, check = TRUE) {
 
     #...............
     # Vector, factor, matrix or data frame for the argument 'x'?
-    if (isTRUE(!is.atomic(x) && !is.factor(x) && !is.matrix(x) && !is.data.frame(x))) {
-
-      stop("Please specifiy a vector, factor, matrix or data frame for the argument 'x'.",
-           call. = FALSE)
-
-    }
+    if (isTRUE(!is.atomic(x) && !is.factor(x) && !is.matrix(x) && !is.data.frame(x))) { stop("Please specifiy a vector, factor, matrix or data frame for the argument 'x'.", call. = FALSE) }
 
     #...............
     # Factor or Vector
     if (isTRUE(is.null(dim(x)))) {
 
-      if (isTRUE(all(!is.na(x)))) {
-
-        warning("There are no missing values (NA) in the vector or factor specified in 'x'.",
-                call. = FALSE)
-
-      }
+      if (isTRUE(all(!is.na(x)))) { warning("There are no missing values (NA) in the vector or factor specified in 'x'.", call. = FALSE) }
 
     #...............
     # Matrix or data frame
     } else {
 
-      if (isTRUE(all(apply(x, 2, function(y)  all(!is.na(y))))))  {
-
-        warning("There are no missing values (NA) in the matrix or data frame specified in 'x'.",
-                call. = FALSE)
-
-      }
+      if (isTRUE(all(apply(x, 2, function(y)  all(!is.na(y)))))) { warning("There are no missing values (NA) in the matrix or data frame specified in 'x'.", call. = FALSE) }
 
     }
 
     #...............
     # Check input 'value'
-    if (isTRUE(length(value) != 1L)) {
-
-      stop("Please specifiy a single value or character string for the argument 'value'.",
-           call. = FALSE)
-
-    }
+    if (isTRUE(length(value) != 1L)) { stop("Please specifiy a single value or character string for the argument 'value'.", call. = FALSE) }
 
   }
 
